#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb 21 08:37:37 2021

@author: nattawoot
"""
import os
import time
from datetime import datetime
from selenium import webdriver
from selenium.common.exceptions import NoSuchElementException

def open_browser(driver_path, url):
    
    loaded = False

    while not loaded:
        try:

            chrome_options = webdriver.ChromeOptions()
            chrome_options.add_argument('disable-notifications')
            
            driver = webdriver.Chrome(executable_path=driver_path, options=chrome_options)
            start = datetime.now()
            driver.set_page_load_timeout(60)
            driver.get(url)

            loaded = True

            return driver, start, [""] * 10
        except Exception as e:
            print(e.__class__.__name__)


def refresh_ssl(driver_path):
    
    try_count = 1
    while try_count<10:
        print(f"try refresh ssl - {try_count}")

        try:
            driver = webdriver.Chrome(executable_path=driver_path)
            driver.get( "http://www.google.com")
            time.sleep(10)
            driver.find_element_by_id("user").send_keys(os.environ['PTTLNG_USER'])
            driver.find_element_by_name("passwd").send_keys(os.environ['PTTLNG_PWD'])
            driver.find_element_by_id("submit").click()        
            driver.quit()
            print("refresh ssl success.")
            break
        
        except NoSuchElementException:
            try_count = try_count + 1
            



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb 21 09:52:32 2021

@author: nattawoot
"""
from collections import namedtuple
import functools
import time

from loguru import logger
            
def dataset_as_namedtuple(data_name, list_of_data, columns):
    Name = namedtuple(data_name, columns)   
    my_set = []
    for t in list_of_data:
        my_set.append(Name(*t))
        
    return my_set


#%% loguru

def logger_wraps(*, entry=True, exit=True, level="DEBUG"):

    def wrapper(func):
        name = func.__name__

        @functools.wraps(func)
        def wrapped(*args, **kwargs):
            logger_ = logger.opt(depth=1)
            if entry:
                logger_.log(level, "Entering '{}' (args={}, kwargs={})", name, args, kwargs)
            result = func(*args, **kwargs)
            if exit:
                logger_.log(level, "Exiting '{}' (result={})", name, result)
            return result

        return wrapped

    return wrapper


def timeit(func):

    def wrapped(*args, **kwargs):
        start = time.time()
        result = func(*args, **kwargs)
        end = time.time()
        logger.debug("Function '{}' executed in {:f} s", func.__name__, end - start)
        return result

    return wrapped




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb 21 08:31:01 2021

@author: nattawoot
"""
import os
import json
import jsonpickle

import boto3
from botocore.client import Config
from botocore.exceptions import ClientError, ParamValidationError
from loguru import logger

from wud.helper import logger_wraps, timeit

jsonpickle.set_encoder_options('json', sort_keys=False, indent=4)

#%% AWS S3
            
            
def get_aws_keys():
    
    # AWS Lambda reserve AWS_ACCESS_KEY_ID, AWS_ACCESS_SECRET_KEY for thier temporary key
    if(os.environ.get('AWS_SESSION_TOKEN')):
        ACCESS_KEY_ID = os.environ.get('AWS_ACCESS_KEY_ID_2')
        ACCESS_SECRET_KEY = os.environ.get('AWS_ACCESS_SECRET_KEY_2')    
    
    else:
        # s3
        ACCESS_KEY_ID = os.environ.get('AWS_ACCESS_KEY_ID')
        ACCESS_SECRET_KEY = os.environ.get('AWS_ACCESS_SECRET_KEY')
        
        #conda not imported above name
        if(ACCESS_SECRET_KEY==None):
            ACCESS_SECRET_KEY = os.environ.get('AWS_SECRET_ACCESS_KEY')
            
    return ACCESS_KEY_ID, ACCESS_SECRET_KEY
            
def get_s3_object(client_resource):
    
    ACCESS_KEY_ID, ACCESS_SECRET_KEY = get_aws_keys()

    
    if client_resource == 'client':
        s3 = boto3.client(
        "s3",
        region_name = 'ap-southeast-1',
        aws_access_key_id = os.environ.get('AWS_ACCESS_KEY_ID'),
        aws_secret_access_key = os.environ.get('AWS_SECRET_ACCESS_KEY'),
        config=Config(signature_version='s3v4')
    )
    else:
        s3 = boto3.resource(
        "s3",
        aws_access_key_id = ACCESS_KEY_ID,
        aws_secret_access_key = ACCESS_SECRET_KEY,
        config=Config(signature_version='s3v4')
    )
        
    return s3            

def s3bucket_img_put(bucket, img_data, name_and_location):
        
    s3 = get_s3_object('resource')

    response = s3.Bucket(bucket).put_object(
        Key=name_and_location, ContentType="image/jpeg", Body=img_data
    )
    logger.success(f"{response} save pic to S3 done")
    
def s3bucket_img_get(bucket, name_and_location):
    
    s3 = get_s3_object('resource')

    file_name = name_and_location.split('/')[-1]
    #output = f"downloads/{file_name}"

    #response = s3.Bucket(bucket).download_file(file_name, output)
    
    file = s3.Object(bucket, name_and_location)
    
    return file
    
    
    #logger.success(f"{response} get pic from S3 done")
    
@timeit
@logger_wraps(exit=False)
def s3bucket_json_get(bucket, file_names):

    s3 = get_s3_object('resource')
    
    if(type(file_names) is str):
        content_object = s3.Object(bucket, file_names)
        file_content = content_object.get()['Body'].read().decode('utf-8-sig')
        json_content = jsonpickle.decode(file_content)
        
        result = json_content
        
    else:
        json_contents = []
        for file_name in file_names:
            content_object = s3.Object(bucket, file_name)
            file_content = content_object.get()['Body'].read().decode('utf-8-sig')
            json_content = jsonpickle.decode(file_content)
            json_contents.append(json_content)
            
        logger.debug(f'get {len(file_names)} from bucket')
    
        result = json_contents
        
    return result 

def s3bucket_json_put(bucket, file_name, json_dict):
    
    s3 = get_s3_object('resource')

    content_object = s3.Object(bucket, file_name)
    object_data = jsonpickle.encode(json_dict)
    content_object.put(Body=object_data)
    
    return 'update done'

def s3bucket_object_put(bucket, file_name, object_data):
    s3 = get_s3_object('resource')

    content_object = s3.Object(bucket, file_name)
    content_object.put(Body=object_data)
    
    return 'upload done'



def s3bucket_list_filter(bucket, filter_keyword):
    
    s3 = get_s3_object('resource')

    my_bucket = s3.Bucket(bucket)
    result = []
    for obj in my_bucket.objects.all():
        if filter_keyword in obj.key:
            result.append(obj.key)
    
    return result

def create_presigned_url(bucket_name, object_name, expiration=21600):
    """Generate a presigned URL to share an S3 object

    :param bucket_name: string
    :param object_name: string
    :param expiration: Time in seconds for the presigned URL to remain valid
    :return: Presigned URL as string. If error, returns None.
    """

    # Generate a presigned URL for the S3 object
    s3 = get_s3_object('client')

    
    try:
        response = s3.generate_presigned_url('get_object',
                                                    Params={'Bucket': bucket_name,
                                                            'Key': object_name},
                                                    ExpiresIn=expiration

                                                    )
    except ClientError as e:
         logger.warning(e)
         return None

    # The response contains the presigned URL
    return response    




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb 21 08:28:49 2021

@author: nattawoot
"""

import os 
from linebot import LineBotApi, WebhookHandler, WebhookParser
from linebot.exceptions import (
    InvalidSignatureError, LineBotApiError
)

from linebot.models import (
 MessageEvent, TextMessage, TextSendMessage, ImageSendMessage, 
 SourceUser, SourceGroup, SourceRoom,
 TemplateSendMessage, ConfirmTemplate, MessageTemplateAction,
 ButtonsTemplate, URITemplateAction, PostbackTemplateAction, ImageCarouselTemplate, ImageCarouselColumn, URIAction,
 CarouselTemplate, CarouselColumn, PostbackEvent,
 StickerMessage, StickerSendMessage, LocationMessage, LocationSendMessage,
 ImageMessage, VideoMessage, AudioMessage, FlexSendMessage, 
 UnfollowEvent, FollowEvent, JoinEvent, LeaveEvent, BeaconEvent,
 FlexSendMessage, BubbleContainer, ImageComponent, BoxComponent,
 TextComponent, IconComponent, ButtonComponent,
 SeparatorComponent, QuickReply, QuickReplyButton, PostbackAction,MessageAction, CarouselContainer

)
from loguru import logger

line_bot_api = LineBotApi(os.environ.get('LINE_CHANNEL_ACCESS_TOKEN'))


#%% line notify
def lineNotify(token, message):
    payload = {'message':message}
    return _lineNotify(token, payload)

def notifyFile(token, filename):
    file = {'imageFile':open(filename,'rb')}
    payload = {'message': 'test'}
    return _lineNotify(token, payload,file)

def notifyPicture(token, url):
    payload = {'message':" ",'imageThumbnail':url,'imageFullsize':url}
    return _lineNotify(token, payload)

def notifySticker(token, stickerID,stickerPackageID):
    payload = {'message':" ",'stickerPackageId':stickerPackageID,'stickerId':stickerID}
    return _lineNotify(token, payload)

def _lineNotify(token, payload,file=None):
    import requests
    url = 'https://notify-api.line.me/api/notify'
    headers = {'Authorization':'Bearer '+token}
    return requests.post(url, headers=headers , data = payload, files=file)

#%% line send message
def send_message(messenger, messenger_id, message):

    if messenger == 'line':
        try:
            line_bot_api.push_message(
                messenger_id,
                TextSendMessage(text=message),
            )
        except LineBotApiError as e:
            logger.warning(f"error send to {messenger_id} fail{e.status_code},{e.error.message},{e.error.details}")

    if messenger == 'fb':
        response = fb_bot.send_text_message(messenger_id, message)
        if ('error' in response):
            logger.debug(f"{messenger_id}-{response}")
    if messenger == 'line_notify':
        response = lineNotify(messenger_id, message)
        if ('error' in response):
            logger.debug(f"{messenger_id}-{response}")
def send_image(messenger, messenger_id, image_link):

    if messenger == 'line':
        try:
            line_bot_api.push_message(
                messenger_id,
                ImageSendMessage(
                    original_content_url=image_link,
                    preview_image_url=image_link,
                ),
            )
            print("sent to-" + messenger_id)
        except LineBotApiError as e:
            logger.warning(f"error send to {messenger_id} fail{e.status_code},{e.error.message},{e.error.details}")
                
    if messenger == 'fb':
        response = fb_bot.send_image_url(messenger_id, image_link)
        if ('error' in response):
            logger.debug(f"{messenger_id}-{response}")

    if messenger == 'line_notify':
        response = notifyPicture(messenger_id, image_link)
        if ('error' in response):
            logger.debug(f"{messenger_id}-{response}")

def send_carousel_flex(messenger_id, json_contents_list, alt_text='flex message'):
    containers = CarouselContainer(
       contents=json_contents_list
    )
    
    message = FlexSendMessage(alt_text=alt_text, contents=containers)
    line_bot_api.push_message(
    messenger_id,
    message
    )




from wud.football import team_name_revise


def test_team_name_revise():
    assert team_name_revise('Chelsea FC', 'footballapi', 'livescore') == 'Chelsea'
    assert team_name_revise('Tottenham Hotspur', 'livescore', 'short') == 'Spurs'
    
    assert team_name_revise("Nankatsu", 'footballapi', 'livescore') == "Nankatsu"


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Apr 26 18:08:49 2021

@author: nattawoot
"""
import pandas as pd
import os
import copy
from collections import namedtuple
from dataclasses import dataclass
from datetime import datetime
from loguru import logger

from wud.aws import s3bucket_json_get

convar_dict = s3bucket_json_get('wud-cloudhouse','maruball_convar.json')



@dataclass
class Match:
    kot: datetime = ''
    team_home: str = ''
    team_away: str = ''
    link: str = ''
    league: str = ''



@dataclass
class MatchBet(Match):
    hdc: float = ''
    hdc_side: str = ''
    odd_home: float = ''
    odd_away: float = ''
    source: str = ''
    

def team_name_revise0(team, source_input, source_output):
    
    
    epl = copy.deepcopy(convar_dict['team_name']['epl'])
    ucl_erp = copy.deepcopy(convar_dict['team_name']['ucl_erp'])
    tpl = copy.deepcopy(convar_dict['team_name']['tpl'])
    etc = copy.deepcopy(convar_dict['team_name']['etc'])

    Team = namedtuple("Team", ['footballapi', 'livescore', 'short', 'league'])   

    
    
    team_set = []
    for t in epl:
        t.append('epl')
        team_set.append(Team(*t))
    for t in ucl_erp:
        t.append('ucl_erp')
        team_set.append(Team(*t))
        
    for t in tpl:
        t.append('tpl')
        team_set.append(Team(*t))
        
    for t in etc:
        t.append('etc')
        team_set.append(Team(*t))
        
        
    result = team
    
    for i in team_set:
        if getattr(i, source_input) == team:
            result = getattr(i, source_output)
            break
        
    return result

def team_name_revise(team, source_input, source_output):
    
    this_folder = os.path.dirname(os.path.abspath(__file__))

    df = pd.read_csv(os.path.join(this_folder,'football_team_name.csv'))
    try:
        row = df.loc[df[source_input] == team]
        result = row.iloc[0][source_output]
    except (IndexError, KeyError):
        logger.warning(f'wud.football.team_name_revise - no register for {team}')
        result = team
        
        if(source_output=='abbv'):
            result = result[:3]

        
    if(pd.isnull(result))   :
        logger.warning(f'wud.football.team_name_revise - blank cell in csv for {team}')
        
        result = team
        if(source_output=='abbv'):
            result = result[:3]
            
    return result       
